@@ -12,16 +12,24 @@
 //    See the License for the specific language governing permissions and
 //    limitations under the License.
 
+//! # Deprecated
+//!
+//! **This crate is no longer being maintained.**
+//!
+//! Fortunately, there's [lots of alternatives](https://crates.io/keywords/bignum) to `ramp`.
+//! Thanks for the good times :`)
+
 #![crate_type = "lib"]
 #![crate_name = "ramp"]
-#![feature(core_intrinsics, asm, allocator_api)]
-#![feature(step_trait, ptr_internals, raw_vec_internals)]
+#![feature(core_intrinsics, allocator_api)]
+#![feature(step_trait, ptr_internals, try_reserve_kind, raw_vec_internals)]
 #![cfg_attr(test, feature(test))]
 
 #[cfg(test)]
 extern crate test;
 
 extern crate alloc;
+extern crate core;
 extern crate hamming;
 extern crate ieee754;
 extern crate num_integer;
@@ -30,6 +38,7 @@ extern crate rand;
 
 pub mod ll;
 mod mem;
+mod raw_vec;
 
 pub mod int;
 pub mod rational;
